@@ -17,6 +17,7 @@ import itertools
 import shlex
 import sys
 
+import autopage.argparse
 import cmd2
 
 
@@ -140,9 +141,16 @@ class InteractiveApp(cmd2.Cmd):
                     parsed = lambda x: x  # noqa
             self.default(parsed('help ' + arg))
         else:
-            cmd2.Cmd.do_help(self, arg)
-            cmd_names = sorted([n for n, v in self.command_manager])
-            self.print_topics(self.app_cmd_header, cmd_names, 15, 80)
+            stdout = self.stdout
+            try:
+                with autopage.argparse.help_pager(stdout) as paged_out:
+                    self.stdout = paged_out
+
+                    cmd2.Cmd.do_help(self, arg)
+                    cmd_names = sorted([n for n, v in self.command_manager])
+                    self.print_topics(self.app_cmd_header, cmd_names, 15, 80)
+            finally:
+                self.stdout = stdout
         return
 
     # Create exit alias to quit the interactive shell.
@@ -158,6 +166,16 @@ class InteractiveApp(cmd2.Cmd):
                 ]
 
     def precmd(self, statement):
+        """Hook method executed just before the command is executed by
+        :meth:`~cmd2.Cmd.onecmd` and after adding it to history.
+
+        :param statement: subclass of str which also contains the parsed input
+        :return: a potentially modified version of the input Statement object
+        """
+        # NOTE(mordred): The above docstring is copied in from cmd2 because
+        # current cmd2 has a docstring that sphinx finds if we don't override
+        # it, and it breaks sphinx.
+
         # Pre-process the parsed command in case it looks like one of
         # our subcommands, since cmd2 does not handle multi-part
         # command names by default.
@@ -175,7 +193,8 @@ class InteractiveApp(cmd2.Cmd):
                 statement.parsed.args = ' '.join(sub_argv)
             else:
                 # cmd2 >= 0.9.1 uses shlex and gives us a Statement.
-                statement = cmd2.Statement(' '.join(sub_argv),
+                statement = cmd2.Statement(
+                    ' '.join(sub_argv),
                     raw=statement.raw,
                     command=cmd_name,
                     arg_list=sub_argv,
@@ -184,7 +203,8 @@ class InteractiveApp(cmd2.Cmd):
                     suffix=statement.suffix,
                     pipe_to=statement.pipe_to,
                     output=statement.output,
-                    output_to=statement.output_to)
+                    output_to=statement.output_to,
+                )
         return statement
 
     def cmdloop(self):
